<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
/**
 * Returns an array contain the settings used for configuring the plugin. 
 */
return array(
		'apisettings_title'=>array(
				'type'=>'title',
				'title'=>__('API Settings', 'braintree'),
				'class'=>array(),
				'value'=>'',
				'description'=>__('In order to start accepting payments using your Braintree account, you will need
						to configure your Braintree API Keys. The API keys can be located by logging into your 
						<a href="https://www.braintreegateway.com/login">Production</a> & <a href="https://sandbox.braintreegateway.com/login">Sandbox account</a>.
						Once logged in, navigate to <span>Acount</span> > <span>My User</span>, and scroll to the bottom of the page
						and click the <span>View Authorizations</span> link.', 'braintree')
		),
		'woocommerce_title'=>array(
				'type'=>'title',
				'title'=>__('WooCommerce Settings', 'braintree'),
				'class'=>array(),
				'value'=>'',
				'description'=>__('On this page, you can maintain settings as they pertain to WooCommerce. To enable this plugin, you must 
						click the checkbox that says <span>Enable</span>. Once enabled, a payment option for Braintree will become available 
						on the checkout page of your site. ')
		),
		'debug_title'=>array(
				'type'=>'title',
				'title'=>__('Debug Log', 'braintree'),
				'class'=>array(),
				'value'=>'',
				'description'=>__('You can ebable debug mode from this page. By enabling debug mode, you can view messages related to transactions within the plugin. 
						This can be helpful when troublshooting payment issues.', 'braintree')
		),
		'license_title'=>array(
				'type'=>'title',
				'title'=>__('License Activation', 'braintree'),
				'class'=>array(),
				'value'=>'',
				'description'=>__('You can activate your license from this page. Once you have purchased a license from <a target="_blank" href="https://wordpress.paymentplugins.com">Payment Plugins</a>
						 you can activate it here. Enter the license key you receive in your order in the license field and click save. If the license activation is not successful, check the debug log for a detailed error message.', 'braintree')
		),
		'subscriptions_title'=>array(
				'type'=>'title',
				'title'=>__('Subscriptions', 'braintree'),
				'class'=>array(),
				'value'=>'',
				'description'=>__('There are two configurable subscription modes with this plugin. You must have WooCoomerce subscriptions enabled in order to accept subscription payments. 
						<div class="div--subscriptionExplanation"><span>Option 1. Braintree Subscriptions</span></div>
						<div>If this mode is enabled, a subscription will be created within Braintree\'s system during checkout. The subscription payment will be charged on the cycle that you configure within the Braintree admin panel. This option is best suited for 
						merchants that want Braintree to handle the subscription payment automatically. If you choose this option, you must ensure you have created a Recurring Billing Plan inside the Braintree admin panel. Once the Recurring Billing Plan has been created, 
						you can assign the plan to your WooCommerce products.</div>
						<div class="div--subscriptionExplanation"><span>Option 2. WooCommerce Subscriptions</span></div>
						<div>If this mode is enabled, subscription payments will be handled by the WooCommerce Subscription plugin. During checkout, the customer\'s payment method will be tokenized, and the token will be saved in your database. When it is time for the subscription 
						payment to be charged, the WooCommerce subscription plugin will use the payment token to run the transaction. This options is best suited for merchants that have complex subscription options such as daily, weekly, or bi-weekly subscription plans.</div>', 'braintree')
		),
		'donations_title'=>array(
				'type'=>'title',
				'title'=>__('Donations Settings', 'braintree'),
				'class'=>array(),
				'value'=>'',
				'description'=>__('On this page you can configure the settings for your donation form. By using short code <span>[braintree_donations]</span> on any of your pages, you can accept 
						donations.', 'braintree')
		),
		'webhooks_title'=>array(
				'type'=>'title',
				'title'=>__('Braintree Webhooks', 'braintree'),
				'class'=>array(),
				'value'=>'',
				'description'=>__('If you have enabled Braintree Webhooks, then your site will be configured to receive messages from Braintree pertaining to subscriptions. For example,
						if webooks are enabled and a customer\'s subscription payment fails, Braintree will send a message to your site indicating the subscription that failed. The plugin will then perform 
						the necessary actions based on Braintree\'s message. All webhooks are based on the Braintree Subscription option being enabled. If you have enabled WooCommerce Subscriptions, then there is no need for webhooks. 
						In order for webhooks to work, you must add a webhook url within your braintree account. Login to your <a target="_blank" href="https://braintreepayments.com/login">Braintree Account</a> and navigate to 
						<span>Settings > Webhooks</span> and click <span>Create a New Webhook</span>. Copy and paste the following url into the <span>Destination URL*</span> field. 
						<input class="input--webhookUrl" type="text" value="'.WC_Braintree_Admin::getWebhooksUrl().'"/>', 'braintree')
		),
		'license_status'=>array(
				'type'=>'custom',
				'title'=>__('License Status', 'braintree'),
				'value'=>'',
				'default'=>'Inactive',
				'class'=>array(),
				'tool_tip'=>true,
				'function'=>'WC_Braintree_Admin::getLicenseStatus',
				'description'=>__('Once you have purchased a license from <a href="https://wordpress.paymentplugins.com">Payment Plugins</a> you will
						be provided with a license key. You can active the license on the license activate page and this will allow you to configure the 
						production mode of the plugin. ', 'braintree')
		),
		'license_status_notice'=>array(
				'type'=>'custom',
				'title'=>__('License Status', 'braintree'),
				'value'=>'',
				'default'=>'Inactive',
				'class'=>array(),
				'tool_tip'=>true,
				'function'=>'WC_Braintree_Admin::getLicenseStatus',
				'description'=>__('Once you have purchased a license from <a href="https://wordpress.paymentplugins.com">Payment Plugins</a> you will
						be provided with a license key. You can active the license on the license activate page and this will allow you to configure the
						production mode of the plugin. ', 'braintree')
		),
		'license'=>array(
				'type'=>'text',
				'value'=>'',
				'default'=>'',
				'title'=>__('License Number', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('This field contains the value of your license key if you have purchased one. It will appear once you have 
						activated your license.', 'braintree')
		),
		'enabled'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Enable Braintree Payments', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('If Braintree Payments is enabled, you can process credit cards and PayPal payments.', 'braintree')
		),
		'production_environment'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Enable Production Mode', 'braintre'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('This setting will enable the prodution mode. You must purchase a license and
						activate your key to maintain this setting. You can purchase a license at 
						<a target="_blank" href="https://wordpress.paymentplugins.com/product-category/braintree-plugins/">Payment Plugins</a>.', 'worldpayus')
		),
		'sandbox_environment'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Enable Sandbox Mode', 'worldpayus'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('This setting will enable sandbox mode. In sandbox mode you can test your integration. If enabled, your sandbox
						API keys will be used to communicate with the <a href="https://sandbox.braintreegateway.com">Braintree Samdbox Environment</a>.', 'worldpayus')
		),
		'production_merchant_id'=>array(
				'type'=>'text',
				'title'=>__('Production Merchant ID', 'braintree'),
				'value'=>'',
				'default'=>'',
				//'disabled'=>true,
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('Your Merchant ID is used to identify you within Braintree\'s environment. You can find your merchant Id by logging 
						into the <a target="_blank" href="https://sandbox.braintreepayments.com/login">Sandbox Environment</a> and navigating to <span>Acount</span> > <span>My User</span>
						> <span>View Authorizations</span>', 'braintree')
		),
		'production_private_key'=>array(
				'type'=>'password',
				'title'=>__('Production Private Key', 'braintree'),
				'value'=>'',
				'default'=>'',
				//'disabled'=>true,
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('The private key is used by Braintree to authenticate each request. You should not share this key with anyone. You can find your merchant Id by logging
						into the <a target="_blank" href="https://sandbox.braintreepayments.com/login">Sandbox Environment</a> and navigating to <span>Acount</span> > <span>My User</span>
						> <span>View Authorizations</span>', 'braintree')
		),
		'production_public_key'=>array(
				'type'=>'text',
				'title'=>__('Production Public Key', 'braintree'),
				'value'=>'',
				'default'=>'',
				//'disabled'=>true,
				'class'=>array('publicKey'),
				'tool_tip'=>true,
				'description'=>__('The public key is used by Braintree to authenticate each request. You can find your merchant Id by logging
						into the <a target="_blank" href="https://sandbox.braintreepayments.com/login">Sandbox Environment</a> and navigating to <span>Acount</span> > <span>My User</span>
						> <span>View Authorizations</span>', 'braintree')
		),
		'sandbox_merchant_id'=>array(
				'type'=>'text',
				'title'=>__('Sandbox Merchant ID', 'braintree'),
				'value'=>'',
				'default'=>'',
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('Your Merchant ID is used to identify you within Braintree\'s environment. You can find your merchant Id by logging
						into the <a target="_blank" href="https://sandbox.braintreepayments.com/login">Sandbox Environment</a> and navigating to <span>Acount</span> > <span>My User</span>
						> <span>View Authorizations</span>', 'braintree')
		),
		'sandbox_private_key'=>array(
				'type'=>'password',
				'title'=>__('Sandbox Private Key', 'braintree'),
				'value'=>'',
				'default'=>'',
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('The private key is used by Braintree to authenticate each request. You should not share this key with anyone. You can find your merchant Id by logging
						into the <a target="_blank" href="https://sandbox.braintreepayments.com/login">Sandbox Environment</a> and navigating to <span>Acount</span> > <span>My User</span>
						> <span>View Authorizations</span>', 'braintree')
		),
		'sandbox_public_key'=>array(
				'type'=>'text',
				'title'=>__('Sandbox Public Key', 'braintree'),
				'value'=>'',
				'default'=>'',
				'class'=>array('publicKey'),
				'tool_tip'=>true,
				'description'=>__('The public key is used by Braintree to authenticate each request. You can find your merchant Id by logging
						into the <a target="_blank" href="https://sandbox.braintreepayments.com/login">Sandbox Environment</a> and navigating to <span>Acount</span> > <span>My User</span>
						> <span>View Authorizations</span>', 'braintree')
		),
		'title_text'=>array(
				'type'=>'text',
				'title'=>__('Title Text', 'braintree'),
				'value'=>'',
				'default'=>'Braintree Payments',
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('The title text is the text that will be displayed on the checkout page. Common values are Credit Card / PayPal.', 'braintree')
		),
		'order_status'=>array(
				'type'=>'select',
				'title'=>__('Order Status', 'braintree'),
				'value'=>array('completed', 'processing', 'pending', 'on-hold'),
				'default'=>'',
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('This is the order status assigned to the order once the payment has been processed by Braintree. Most merchants
						use processing or complete.', 'braintree')
		),
		'order_prefix'=>array(
				'type'=>'text',
				'title'=>__('Order Prefix', 'braintree'),
				'value'=>'',
				'default'=>'',
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('The order prefix is appened to the order id and used by Braintree. This settings can be helpful if you want to distinguish
						orders that came from this particular site or plugin.', 'braintree')
		),
		'payment_methods'=>array(
				'type'=>'checkbox',
				'value'=>Braintree_PaymentMethods::paymentMethods(),
				'default'=>'',
				'title'=>__('Display Payment Methods', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('If you want to display an image of the payment methods on the
						checkout page that your Braintree account accepts, select the checkboxes.', 'braintree')
		),
		'paypal_only'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Only Allow Paypal', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('If you only want to use this plugin to accept PayPal, enable it here. In addition to this setting, you 
						must make sure you enabled PayPal from within the Braintree Control Panel.', 'braintree')
		),
		'enable_debug'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Enable Debug Mode', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('If you need to troubleshoot payment transactions, enable debug mode. You can view the debug messages on this page.', 'braintree')
		),
		'woocommerce_subscriptions'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('WooCommerce Subscriptions', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('Enable this mode if you want the WooCommerce Subscriptions plugin to handle the subscription payment.', 'braintree')
		),
		'braintree_subscriptions'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Braintree Subscriptions', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('Enable this mode if you want the subscription to be creaetd in the Braintree system and handled automatically by Braintree. When this setting is enabled,
						you must create a planId in Braintree and assign the planId to your subscription products.', 'braintree')
		),
		'braintree_subscriptions_charge_failed'=>array(
				'type'=>'select',
				'options'=>Braintree_Manager::getSubscriptionStatuses(),
				'default'=>'wc-pending-cancel',
				'title'=>__('Status - Payment Failed', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('If you have enabled webooks, this is the status assigned to the WooCommerce Subscription object when the subscription charge is unsuccesful. You must
						enable webhooks from within the Braintree Admin Panel. Instructions can be found on <a href="https://braintreepayments.com">Braintree</a> on how to setup a webhook.', 'braintree')
		),
		'braintree_subscriptions_charge_success'=>array(
				'type'=>'select',
				'options'=>Braintree_Manager::getSubscriptionStatuses(),
				'default'=>'wc-active',
				'title'=>__('Status - Payment Succes', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('If you have enabled webooks, this is the status assigned to the WooCommerce Subscription object when the subscription charge is successful. You must
						enable webhooks from within the Braintree Admin Panel. Instructions can be found on <a href="https://braintreepayments.com">Braintree</a> on how to setup a webhook.', 'braintree')
		),
		'braintree_subscriptions_active'=>array(
				'type'=>'select',
				'options'=>Braintree_Manager::getSubscriptionStatuses(),
				'default'=>'wc-active',
				'title'=>__('Status - Subscription Active', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('If you have enabled webooks, this is the status assigned to the WooCommerce Subscription object when the subscription has gone active. You must
						enable webhooks from within the Braintree Admin Panel. Instructions can be found on <a href="https://braintreepayments.com">Braintree</a> on how to setup a webhook.', 'braintree')
		),
		'braintree_subscriptions_expired'=>array(
				'type'=>'select',
				'options'=>Braintree_Manager::getSubscriptionStatuses(),
				'default'=>'wc-expired',
				'title'=>__('Status - Subscription Expired', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('If you have enabled webooks, this is the status assigned to the WooCommerce Subscription object when the subscription has expired. You must
						enable webhooks from within the Braintree Admin Panel. Instructions can be found on <a href="https://braintreepayments.com">Braintree</a> on how to setup a webhook.', 'braintree')
		),
		'braintree_subscriptions_past_due'=>array(
				'type'=>'select',
				'options'=>Braintree_Manager::getSubscriptionStatuses(),
				'default'=>'wc-pending-cancel',
				'title'=>__('Status - Subscription Past Due', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('If you have enabled webooks, this is the status assigned to the WooCommerce Subscription object when the subscription has gone past due. You must
						enable webhooks from within the Braintree Admin Panel. Instructions can be found on <a href="https://braintreepayments.com">Braintree</a> on how to setup a webhook.', 'braintree')
		),
		'braintree_subscriptions_cancelled'=>array(
				'type'=>'select',
				'options'=>Braintree_Manager::getSubscriptionStatuses(),
				'default'=>'wc-cancelled',
				'title'=>__('Status - Subscription Past Due', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('If you have enabled webooks, this is the status assigned to the WooCommerce Subscription object when the subscription has been cancelled. You must
						enable webhooks from within the Braintree Admin Panel. Instructions can be found on <a href="https://braintreepayments.com">Braintree</a> on how to setup a webhook.', 'braintree')
				
		),
		'braintree_subscriptions_mixed_cart'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Mixed Shopping Cart', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('Enable this setting if you want to allow products and subscriptions to be added to the shopping cart at the same time when there is a 
						Braintree Subscription in the cart.', 'braintree')
		),
		'subscriptions_payment_success_status'=>array(
				'type'=>'select',
				'options'=>array(
						'wc-pending'        => _x( 'Pending', 'Subscription status', 'woocommerce-subscriptions' ),
					    'wc-active'         => _x( 'Active', 'Subscription status', 'woocommerce-subscriptions' ),),
				'default'=>'modal',
				'title'=>__('Subscription Status - Payment Success', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('This setting determines the status of the subscription when the payment is processed.', 'braintree')
		),
		'subscriptions_payment_failed_status'=>array(
				'type'=>'select',
				'options'=>Braintree_Manager::getSubscriptionStatuses(),
				'default'=>'modal',
				'title'=>__('Subscription Status - Payment Failed', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('This setting determines the status of the subscription when the payment fails during subscription processing.
						<span class="example">Example:If you want the customer\'s subscription to be cancelled if their payment fails during a recurring payment, set the status to cancelled.</span>', 'braintree')
		),
		/* 'braintree_subscriptions_prefix'=>array(
				'type'=>'text',
				'value'=>'',
				'default'=>'',
				'title'=>__('Subscription Prefix', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('If you would like the subscription orderId to contain an order prefix, you can add one here. If left blank, the subscription prefix
						will consist of the orderId.', 'braintree')
		), */
		'woocommerce_subscriptions_prefix'=>array(
				'type'=>'text',
				'value'=>'',
				'default'=>'',
				'title'=>__('Subscription Prefix', 'braintree'),
				'class'=>array('subItem', 'prefixInput'),
				'tool_tip'=>true,
				'description'=>__('If you would like the subscription orderId to contain an order prefix, you can add one here. If left blank, the subscription prefix
						will consist of the orderId.', 'braintree')
		),
		'donation_button_design'=>array(
				'type'=>'title',
				'title'=>__('Button Design Settings', 'braintree'),
				'class'=>array('h1--DonationButtonDesign'),
				'value'=>'',
				'description'=>__('You can configure the look and feel of your donation button with the following settings.', 'braintree')
		),
		'donation_form_layout'=>array(
				'type'=>'select',
				'value'=>array('modal', 'inline'),
				'default'=>'modal',
				'title'=>__('Form Layout', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('The form layout has two options. If modal is selected, the form will appear as a popup when the donator
						clicks the donation button. If inline is selected, the donation form will appear inside the html of the page.', 'braintree')
		),
		'donation_button_text'=>array(
				'type'=>'text',
				'value'=>'Donate',
				'default'=>__('Donate', 'braintree'),
				'title'=>__('Button Text', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('You can customize the text that appears on the donation button by entering the text here.', 'braintree')
		),
		'donation_button_background'=>array(
				'type'=>'text',
				'value'=>'#61D395',
				'default'=>'#61D395',
				'title'=>__('Background Color', 'braintree'),
				'class'=>array('donationColor'),
				'tool_tip'=>true,
				'description'=>__('You can customize the background color of the donation button by selecting a color from the color picker.', 'braintree')
		),
		'donation_button_border'=>array(
				'type'=>'text',
				'value'=>'#61D395',
				'default'=>'#61D395',
				'title'=>__('Border Color', 'braintree'),
				'class'=>array('donationColor'),
				'tool_tip'=>true,
				'description'=>__('You can customize the border color of the donation button by selecting a color from the color picker.', 'braintree')
		),
		'donation_button_text_color'=>array(
				'type'=>'text',
				'value'=>'#61D395',
				'default'=>'#ffffff',
				'title'=>__('Text Color', 'braintree'),
				'class'=>array('donationColor'),
				'tool_tip'=>true,
				'description'=>__('You can customize the text color of the button.', 'braintree')
		),
		'donation_modal_button_text'=>array(
				'type'=>'text',
				'value'=>'Some Text',
				'default'=>__('Donate', 'braintree'),
				'title'=>__('Modal Button Text', 'braintree'),
				'class'=>array('subItem', 'modalOption'),
				'tool_tip'=>true,
				'description'=>__('If you have enabled the modal donation form, you can control the text that is displayed for the button that when clicked displays
						the modal donation form.', 'braintree')
				
		),
		'donation_modal_button_background'=>array(
				'type'=>'text',
				'value'=>'#61D395',
				'default'=>'#61D395',
				'title'=>__('Background Color', 'braintree'),
				'class'=>array('donationColor', 'subItem', 'modalOption'),
				'tool_tip'=>true,
				'description'=>__('You can customize the the background color of the modal donation button by selecting a color from the color picker.', 'braintree')
		),
		'donation_modal_button_border'=>array(
				'type'=>'text',
				'value'=>'#61D395',
				'default'=>'#61D395',
				'title'=>__('Border Color', 'braintree'),
				'class'=>array('donationColor', 'subItem', 'modalOption'),
				'tool_tip'=>true,
				'description'=>__('You can customize the border color of the modal donation button by selecting a color from the color picker.', 'braintree')
		),
		'donation_modal_button_text_color'=>array(
				'type'=>'text',
				'value'=>'#61D395',
				'default'=>'#ffffff',
				'title'=>__('Text Color', 'braintree'),
				'class'=>array('donationColor', 'subItem', 'modalOption'),
				'tool_tip'=>true,
				'description'=>__('You can customize the color of the text with this option.', 'braintree')
		),
		'donation_address'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Capture Billing Address', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('If enabled, the donation form will have address fields for capturing the donor\'s billing address.', 'braintree')
		),
		'donation_email'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Capture Email', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('If enabled, the donation form will have a field for capturing the donor\'s email address. If you have enabled email receipts from within Braintree,
						then this is a required setting.', 'braintree')
		),
		'donation_name'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Capture Donor Name', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('If enabled, the donation form will have fields for capturing the donor\'s name.', 'braintree')
		),
		'donation_success_url'=>array(
				'type'=>'text',
				'value'=>'',
				'default'=>'',
				'title'=>__('Success URL', 'braintree'),
				'class'=>array('donation-url'),
				'tool_tip'=>true,
				'description'=>__('Enter the url of the page/site you would like the customer to be redirected to after the donation.', 'braintree')
				
		),
		'donation_currency'=>array(
				'type'=>'custom',
				'function'=>'WC_Braintree_Admin::getCountriesOptions',
				'default'=>'USD',
				'title'=>__('Donation Currency', 'braintree'),
				'class'=>array(''),
				'tool_tip'=>true,
				'description'=>__('You can set the currency that will display on the amount field. Ensure this currencyy matches the currency for your Braintree Account.', 'braintree')
		),
		'donation_default_country'=>array(
				'type'=>'select',
				'options'=>Braintree_Countries::$countries,
				'title'=>__('Donation Country', 'braintree'),
				'class'=>array('subItem', 'addressOption'),
				'tool_tip'=>true,
				'description'=>__('You can set the default country that will appear on the donation form.', 'braintree')
		),
		'donation_merchant_account_id'=>array(
				'type'=>'text',
				'value'=>'',
				'default'=>'',
				'title'=>__('Merchant Account Id', 'braintree'),
				'class'=>array(''),
				'tool_tip'=>true,
				'description'=>__('NOTE: Not to be confused with the API key Merchant ID. The Merchant Account ID determines the currency that the donation is settled in. You can find your Merchant Account Id by logging into Braintree,
						and clicking Settings > Processing and scrolling to the bottom of the page.', 'braintree')
		),
		'donation_payment_methods'=>array(
				'type'=>'checkbox',
				'value'=>Braintree_PaymentMethods::paymentMethods(),
				'default'=>'',
				'title'=>__('Display Payment Methods', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('If you want to display an image of the payment methods on the
						checkout page that your Braintree account accepts, select the checkboxes.', 'braintree')
		),
		'enable_webhooks'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Enable Webhooks', 'braintree'),
				'class'=>array(),
				'tool_tip'=>true,
				'description'=>__('If Webhooks are enabled, you must enable Braintree Subscriptions on the Subscriptions page.', 'braintree')
		),
		'webhook_subscription_charged_unsuccessfully'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Subscription Payment Failed', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('If enabled, Braintree will send a message containing the information of the failed subscription payment. The status of the subscription will be set to on hold.', 'braintree')
				
		),
		'webhook_subscription_expired'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Subscription Expired', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('If enabled, Braintree will send a message containing the information of the expired subscription. The status of the subscription will be set to expired.', 'braintree')
		),
		'webhook_subscription_past_due'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Subscription Payment Past Due', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('If enabled, Braintree will send a message containing the information of the past due subscription. The status of the subscription will be set to expired.', 'braintree')
		),
		'webhook_subscription_went_active'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Subscription Active', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('If enabled, Braintree will send a message containing the information of the active subscription. The status of the subscription will be set to active.', 'braintree')
		),
		'webhook_subscription_charged_successfully'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Subscription Charge Success', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('If enabled, Braintree will send a message containing the information of the successful subscription charge. The transaction id will be added to the order note for future reference.', 'braintree')
		),
		'webhook_subscription_cancelled'=>array(
				'type'=>'checkbox',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Subscription Cancelled', 'braintree'),
				'class'=>array('subItem'),
				'tool_tip'=>true,
				'description'=>__('If enabled, Braintree will send a message containing the information of the cancelled subscription. The transaction id will be added to the order note for future reference.', 'braintree')
		),
		'woocommerce_braintree_merchant_acccounts'=>array(
				'type'=>'custom',
				'function'=>'WC_Braintree_Admin::displayMerchantAccounts',
				'value'=>'yes',
				'default'=>'',
				'title'=>__('Merchant Account ID\'s', 'braintree'),
				'class'=>array(''),
				'tool_tip'=>true,
				'description'=>__('Add additional Merchant Account ID\' if you don\'t want to use your default Merchant Account ID.', 'braintree')
				
		)
);